pro select_GPIPS_FOVs
;
; selects those GPIPS FOVs that overlap the user selected coordinate
; center and field size(s)
; 
; DPC   20200519
; 
; ---------------------------------------------------------------------
; 
;   read the summary file
;   
; must be in directory with the summary table file
;
;file_in = '20190711_GPIPS_DR4_Summary.dat'
;readcol,file_in,skipline=3,gp,gp_l,gp_b,format='I,D,D'
;;
; read the GL, GB vectors
; 
GPIPS_GL_GB, gp_l, gp_b
;
ngp = N_ELEMENTS(gp_l)
gp = indgen(ngp)+1
;
print, 'Summary file of ',ngp,' FOVs read'
;
name = ''
read, prompt='Object or Field Designation (string): ',name
;
read, prompt='Plot to screen (0) or file (1): ',jplot
if(jplot eq 1) then begin
  out_file = dialog_pickfile(title='Select output PS file')
endif
;
; set up plotting
; 
device, decomposed=0
loadct, 0     ; BW for images, but add colors
;
tvlct, [0,255,130,255,0,0,255,255,117],[0,255,130,0,255,0,255,102,26],[0,255,130,0,0,255,0,0,3],0
lt_gray = 2
red = 3
green = 4
blue = 5
yellow = 6
orange = 7
brown = 8
;
xch = 3         ; character sizes for labels, numbers
ych = 3
;
if(jplot eq 0) then begin
  black=0
  white=1
  chsz=1.3
  chthick=2
  SET_PLOT, 'WIN'
  Window, 20, xsize=750, ysize=750
  thick=3
  xmar = [10,3]
  ymar = [6,2]
endif
;
if(jplot ne 0) then begin
  ;
  SET_PLOT, 'PS'
  !P.FONT=1
  DEVICE, /TIMES, FONT_SIZE=13, /PORTRAIT, /ENCAPSUL, $
    /COLOR , XSIZE=24, YSIZE=24; XOFFSET=2 ; YOFFSET=24
  black = 1   ; 1
  white = 0   ; 0
  chsz = 1.35
  chthick = 3
  thick=5
  xmar = [10,3]
  ymar = [6,6]
  ;
  DEVICE, FILENAME=out_file
endif
;
read, prompt='Select Coordinate Input Type (1=RA/Dec Sexigesimal; 2=RA/Dec Degrees; 3=GL/GB Degrees: ',itype
xcoord = ''
ycoord = ''
read, prompt='Enter RA or GL: ',xcoord
read, prompt='Enter Dec or GB: ',ycoord
read, prompt='Search radius (arcmin) = ',rad
;
; convert to L,B if needed
; 
case itype of
  1: begin
        parts = STRSPLIT(xcoord,'[ +:;dhmsDHMS]',/extract,count=count)
        if(count eq 3) then begin
          ra = double(parts[0]) + double(parts[1])/60.0 + double(parts[2])/3600.0
          ra *= 15.0    ; convert to degrees
        endif else print, 'invalid input, try again'
        dparts = STRSPLIT(ycoord,'[ +:;dhmsDHMS]',/extract,count=dcount)
        if(dcount eq 3) then begin
          dec = abs(double(dparts[0])) + double(dparts[1])/60.0 + double(dparts[2])/3600.0
          ind = strpos(ycoord,'-')
          if(ind ne -1) then dec *= -1.0d0
        endif else print, 'invalid input, try again'
        ;
        print, 'RA, Dec in Hours, Deg = ',ra, dec
        ;
        ; convert to GL, GB
        ;
        glactc, ra, dec, 2000.0, gl, gb, 1, /degree
     end
  2: begin
      ra = xcoord
      dec = ycoord
      ;
      ; convert to GL, GB
      ;
      glactc, ra, dec, 2000.0, gl, gb, 1, /degree
     end
  3: begin
      gl = xcoord
      gb = ycoord
     end
  else: begin
          print, 'invalid input, try again'
        end
endcase
;
print, 'Searching about GL, GB = ',gl, gb
;
; find all the centers within the search radius plus 7.1 arcmin
;   (half diagonal size of a FOV)
;
search_rad = rad + 7.1
search_rad /= 60.0        ; into deg
;
match_FOV = 0
nmatch = 0
;
lmin = 90.0
lmax = 0.
bmin = 2.0
bmax = -2.0
;
for i = 0, ngp-1 do begin
  ;
  dif_gl = gl - gp_l[i]
  dif_gb = gb - gp_b[i]
  ;
  rad_dist = sqrt((dif_gl)^2 + (dif_gb)^2)
  if(rad_dist le search_rad) then begin
      if(nmatch eq 0) then begin
        match_FOV = [i+1]
      endif else begin
        match_FOV = [match_FOV,i+1]
      endelse
      ;
      nmatch++
      ;
      lmin = lmin < gp_l[i]
      lmax = lmax > gp_l[i]
      bmin = bmin < gp_b[i]
      bmax = bmax > gp_b[i]
  endif
endfor
lmin -= 0.14
lmax += 0.14
bmin -= 0.14
bmax += 0.14
;
print, 'Number of FOVs w/i search radius = ',nmatch
;
; print the list of GP numbers
;
if(nmatch gt 0) then begin
  print, 'List of GPIPS FOVS:'
  ;
  for j = 0, nmatch-1 do begin
    print, 'GP'+string(match_FOV[j],format='(I4.4)')
  endfor
endif
;
; plot
;
xr = [lmin, lmax]
yr = [bmin, bmax]
plot, xr, yr, xs=1, ys=1, xtitle='GL (deg)',ytitle='GB (deg)',title=name,/isotropic,/nodata,$
    charthick=thick, charsize=chsz, $
    xtickinterval = 0.2, xcharsize=chsz, $
    ytickinterval = 0.2, ycharsize=chsz,$
    position=position,$
    thick=thick, $
    xthick=thick, ythick =thick, $
    xminor=2, xmar = xmar, $
    yminor=2, ymar = ymar, $
    background=black,color=white
;
  
for i = 0, nmatch-1 do begin
  igp = match_FOV[i]-1
  ;
  this_l = gp_l[igp]
  this_b = gp_b[igp]
  this_gp = match_FOV[i]
  ;
  ; find corners of Mimir FOV for plotting
  ;
  glactc, this_ra, this_dec, 2000.0, this_l, this_b, 2, /degree
  ;
  ; add 5 arcmin to dec and recompute l, b
  ;
  glactc, this_ra, this_dec+(5./60.), 2000.0, that_l, that_b, 1, /degree
  ;
  ; angle (in radians)
  ;
  angle = atan((that_b - this_b),(that_l - this_l))
  ;
  box_l = [-1.,1.,1.,-1.,-1.]
  box_b = [-1.,-1.,1.,1.,-1.]
  ;
  rot_box_l = box_l * cos(angle) - box_b * sin(angle)
  rot_box_b = box_b * cos(angle) + box_l * sin(angle)
  ;
  scale = (4.5/60.)
  ;
  oplot, this_l+scale*rot_box_l, this_b+scale*rot_box_b, psym=-3,linestyle=1, thick=thick, color=blue
  ;
  xyouts, this_l, this_b, string(this_gp,format='(I4.4)'), charsize=chsz,charthick=thick, align=0.5,color=blue
endfor
;
; mark the target field
;
xp = fltarr(47)
yp = fltarr(47)
;
xs = fltarr(47)
ys = fltarr(47)
;
for j = 0, 46 do begin
  theta = 2.0*!PI*float(j/46.)
  ;
  xp[j] = gl + search_rad * cos(theta)
  yp[j] = gb + search_rad * sin(theta)
  ;
  ; smaller search radius
  ;
  xs[j] = gl + (rad/60.) * cos(theta)
  ys[j] = gb + (rad/60.) * sin(theta)
  ;
endfor
oplot, xp, yp, psym=-3, color=green,thick=thick,linestyle=1
oplot, xs, ys, psym=-3, color=green, thick=thick, linestyle=0
;
; and the inner search radius
; 
oplot, xp, yp, psym=-3, color=green,thick=thick
;
; mark center
;
xyouts, gl, gb, 'X',charsize=chsz,align=0.5,color=red,charthick=thick
oplot, gl+scale*rot_box_l, gb+scale*rot_box_b, psym=-3,linestyle=0,color=red,thick=thick
;
;
if(jplot ne 0) then begin
  DEVICE,/CLOSE
  ;
  SET_PLOT, 'Win'
endif else begin
  cursor, xx, yy, /wait
  wait, 1
  WDELETE, 20
endelse
;
!P.MULTI = 0
;
print, 'Done!'
end